@@ -11,7 +11,7 @@ Pandoc - wrapper for the mighty Pandoc document converter
 
 =cut
 
-our $VERSION = '0.8.1';
+our $VERSION = '0.8.2';
 
 use Pandoc::Version;
 use Carp 'croak';
@@ -221,7 +221,9 @@ sub data_dir {
 }
 
 sub pandoc_data_dir {
-    File::Spec->catdir($ENV{HOME} || $ENV{USERPROFILE}, '.pandoc', @_);
+    my $home = $ENV{HOME} || $ENV{USERPROFILE}
+        || File::Spec->catpath($ENV{HOMEDRIVE}, $ENV{HOMEPATH}, '');
+    File::Spec->catdir($home, '.pandoc', @_);
 }
 
 sub bin {
